@@ -9,7 +9,7 @@ from . import remove_bad_px
 from . import remove_vignetting
 from . import spectral_debending
 from . import voronoi_partitioning
-from . import form_mirror_sep_axis
+from . import import_mirror_sep
 from . import basic_math
 
 from .fill_gaps import *
@@ -23,4 +23,5 @@ from .remove_bad_px import *
 from .remove_vignetting import *
 from .spectral_debending import *
 from .voronoi_partitioning import *
+from .import_mirror_sep import *
 from .basic_math import *
